# Generated by roxygen2: do not edit by hand

export(augment_trends)
export(decompose_series)
export(deseason_series)
export(detrend_series)
export(df_to_ts)
export(extract_trends)
export(ts_to_df)
importFrom(RcppRoll,roll_mean)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(cli,cli_warn)
importFrom(hpfilter,hp1)
importFrom(hpfilter,hp2)
importFrom(lubridate,month)
importFrom(lubridate,quarter)
importFrom(lubridate,year)
importFrom(rlang,`!!`)
importFrom(rlang,`:=`)
importFrom(rlang,caller_env)
importFrom(stats,AIC)
importFrom(stats,StructTS)
importFrom(stats,cycle)
importFrom(stats,decompose)
importFrom(stats,filter)
importFrom(stats,fitted)
importFrom(stats,frequency)
importFrom(stats,is.ts)
importFrom(stats,lm)
importFrom(stats,loess)
importFrom(stats,poly)
importFrom(stats,predict)
importFrom(stats,residuals)
importFrom(stats,setNames)
importFrom(stats,smooth.spline)
importFrom(stats,start)
importFrom(stats,stl)
importFrom(stats,time)
importFrom(stats,ts)
importFrom(stats,tsSmooth)
importFrom(stats,var)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tsbox,ts_df)
importFrom(tsbox,ts_ts)
